@@ -17,6 +17,13 @@ use Digest::SHA qw(sha1_hex);
 use Text::Patch;
 use Config;
 
+$SIG{__WARN__} = sub {
+	my $thing =  join('', @_);
+	$thing    =~ s|(://.+:).+(\@.+)|$1******$2|;
+	warn $thing;
+	return 1;
+};
+
 sub ACTION_build {
   my $self = shift;
   # as we want to wipe 'sharedir' during 'Build clean' we has
@@ -37,7 +44,7 @@ sub ACTION_install
 {
  my $self = shift;
  my $sharedir = '';
- 
+
  $sharedir = eval {File::ShareDir::dist_dir('Alien-SDL')} || '';
 
  if ( -d $sharedir )
@@ -84,6 +91,7 @@ sub ACTION_code {
     if($bp->{buildtype} eq 'use_config_script') {
       $self->config_data('script', $bp->{script});
       # include path trick - adding couple of addititonal locations
+      $self->set_ld_config($build_out);
       $self->config_data('additional_cflags', '-I' . $self->get_path($bp->{prefix} . '/include/smpeg') . ' '.
                                               '-I' . $self->get_path($bp->{prefix} . '/include') . ' ' .
                                               $self->get_additional_cflags);
@@ -95,6 +103,7 @@ sub ACTION_code {
       $self->clean_dir($build_out);
       $self->extract_binaries($download, $build_out);
       $self->set_config_data($build_out);
+      $self->set_ld_config($build_out);
     }
     elsif($bp->{buildtype} eq 'build_from_sources' ) {
       # all the following functions die on error, no need to test ret values
@@ -103,6 +112,7 @@ sub ACTION_code {
       $self->clean_dir($build_out);
       $self->build_binaries($build_out, $build_src);
       $self->set_config_data($build_out);
+      $self->set_ld_config($build_out);
     }
 
     # mark sucessfully finished build
@@ -116,6 +126,17 @@ sub fetch_file {
   my ($self, $url, $sha1sum, $download) = @_;
   die "###ERROR### _fetch_file undefined url\n"     unless @{$url}[0];
   die "###ERROR### _fetch_file undefined sha1sum\n" unless $sha1sum;
+
+  # setting http_proxy environment var if we are within CPAN and this information is available
+  if(!$ENV{http_proxy} && $ENV{PERL5_CPAN_IS_RUNNING}) {
+    if(eval('require CPAN::Config; 1') && $CPAN::Config->{http_proxy}) {
+      $ENV{http_proxy} = $CPAN::Config->{http_proxy};
+      if($CPAN::Config->{proxy_user} && $CPAN::Config->{proxy_pass} && $CPAN::Config->{http_proxy} !~ m|//.+:.+@|) {
+        $ENV{http_proxy} =~ s|://|://\Q$CPAN::Config->{proxy_user}\E:\Q$CPAN::Config->{proxy_pass}\E@|;
+      }
+    }
+  }
+
   my $ff = File::Fetch->new(uri => @{$url}[0]);
   my $fn = catfile($download, $ff->file);
   if (-e $fn) {
@@ -167,6 +188,9 @@ sub extract_binaries {
   # fix hardcoded prefix path in bin/sdl-config
   my ($version, $prefix, $incdir, $libdir) = find_SDL_dir(rel2abs($build_out));
   sed_inplace("$prefix/bin/sdl-config", 's/^prefix=.*/prefix=\''.quotemeta($prefix).'\'/');
+  if( $^O eq 'MSWin32' && $My::Utility::cc eq 'cl' ) {
+    cp( catfile('patches', 'SDL_config_win32.h'), catfile($incdir, 'SDL', 'SDL_config.h') );
+  }
 }
 
 sub extract_sources {
@@ -217,19 +241,22 @@ sub set_config_data {
   $self->config_data('share_subdir', abs2rel($prefix, rel2abs('sharedir')));
 
   # set defaults
-  my $cfg = {
-    # defaults
-    version     => $version,
-    prefix      => '@PrEfIx@',
-    libs        => '-L' . $self->get_path('@PrEfIx@/lib') . ' -lSDLmain -lSDL',
-    cflags      => '-I' . $self->get_path('@PrEfIx@/include/SDL') . ' -D_GNU_SOURCE=1 -Dmain=SDL_main',
-    shared_libs => [ ],
-  };
+  my $L   = $My::Utility::cc eq 'cl'
+          ? '/LIBPATH:'
+          : '-L';
+  my $cfg = $self->config_data('config') || {};
+
+  # defaults
+  $cfg->{version}        = $version;
+  $cfg->{prefix}         = '@PrEfIx@';
+  $cfg->{libs}           = $L . $self->get_path('@PrEfIx@/lib') . ' -lSDLmain -lSDL';
+  $cfg->{cflags}         = '-I' . $self->get_path('@PrEfIx@/include/SDL') . ' -D_GNU_SOURCE=1 -Dmain=SDL_main';
+  $cfg->{ld_shared_libs} = [ ];
 
   # overwrite values available via sdl-config
-  my $bp = $self->config_data('build_prefix') || $prefix;
+  my $bp      = $self->config_data('build_prefix') || $prefix;
   my $devnull = File::Spec->devnull();
-  my $script = rel2abs("$prefix/bin/sdl-config");
+  my $script  = $self->escape_path( rel2abs("$prefix/bin/sdl-config") );
   foreach my $p (qw(version prefix libs cflags)) {
     my $o=`$script --$p 2>$devnull`;
     if ($o) {
@@ -239,11 +266,22 @@ sub set_config_data {
     }
   }
 
+  # write config
+  $self->config_data('additional_cflags', '-I' . $self->get_path('@PrEfIx@/include') . ' ' .
+                                          '-I' . $self->get_path('@PrEfIx@/include/smpeg') . ' ' .
+                                          $self->get_additional_cflags);
+  $self->config_data('additional_libs', $self->get_additional_libs);
+  $self->config_data('config', $cfg);
+}
+
+sub set_ld_config {
+  my( $self, $build_out ) = @_;
+  my ($version, $prefix, $incdir, $libdir) = find_SDL_dir(rel2abs($build_out));
+  my $cfg   = $self->config_data('config') || {};
   my $dlext = get_dlext();
   # find ld_shared_libs and create symlinks if necessary
   my $symlink_exists = eval { symlink("",""); 1 };
-  if($symlink_exists)
-  {
+  if($symlink_exists) {
     my @shlibs_ = find_file($build_out, qr/\.$dlext[\d\.]+$/);
     foreach my $full (@shlibs_){
       $full =~ qr/(.*\.$dlext)[\d\.]+$/;
@@ -254,9 +292,8 @@ sub set_config_data {
 
   # find and set ld_shared_libs
   my @shlibs = find_file($build_out, qr/\.$dlext$/);
-  my $p = rel2abs($prefix);
-  $_ =~ s/^\Q$prefix\E/\@PrEfIx\@/ foreach (@shlibs);
-  $cfg->{ld_shared_libs} = [ @shlibs ];
+#  my $p      = rel2abs($prefix);
+  $_         =~ s/^\Q$prefix\E/\@PrEfIx\@/ foreach (@shlibs);
 
   # set ld_paths and ld_shlib_map
   my %tmp = ();
@@ -269,9 +306,9 @@ sub set_config_data {
       $shlib_map{smpeg} = $full unless $shlib_map{smpeg};
     }
     elsif ($f =~ /^(lib)?(png12)/) {
-      $shlib_map{png12} = $full unless $shlib_map{png12};
+      $shlib_map{png12} = $full unless $shlib_map{png12}; # what if it isnt png12?
     }
-    elsif ($f =~ /^(lib)?(tiff|jpeg|png)[^a-zA-Z]/) {
+    elsif ($f =~ /^(lib)?(intl|z|tiff|jpeg|png|ogg|vorbis|vorbisfile|freetype|FLAC|mikmod)[^a-zA-Z]/) {
       $shlib_map{$2} = $full unless $shlib_map{$2};
     }
     elsif ($f =~ /^(lib)?(SDL_[a-zA-Z]{2,8})[^a-zA-Z0-9]/) {
@@ -283,14 +320,21 @@ sub set_config_data {
       $shlib_map{SDL} = $full unless $shlib_map{SDL};
     }
   };
-  $cfg->{ld_paths} = [ keys %tmp ];
-  $cfg->{ld_shlib_map} = \%shlib_map;
 
-  # write config
-  $self->config_data('additional_cflags', '-I' . $self->get_path('@PrEfIx@/include') . ' ' .
-                                          '-I' . $self->get_path('@PrEfIx@/include/smpeg') . ' ' .
-                                          $self->get_additional_cflags);
-  $self->config_data('additional_libs', $self->get_additional_libs);
+  $cfg->{ld_shared_libs} = [ @shlibs ];
+  $cfg->{ld_paths}       = [ keys %tmp ];
+  $cfg->{ld_shlib_map}   = \%shlib_map;
+
+  my $have_libs = $self->notes('have_libs');
+  for(qw(pthread  z jpeg tiff png ogg vorbis vorbisfile freetype
+         pangoft2 pango gobject gmodule glib fontconfig expat )) {
+    if( !$shlib_map{$_} && $have_libs->{$_}->[0] ) {
+      next unless defined $have_libs->{$_}->[1];
+      push @{ $cfg->{ld_shared_libs} }, $have_libs->{$_}->[1];
+      $shlib_map{$_} = $have_libs->{$_}->[1];
+    }
+  }
+
   $self->config_data('config', $cfg);
 }
 
@@ -332,6 +376,12 @@ sub clean_dir {
   }
 }
 
+sub escape_path {
+  # this needs to be overriden in My::Builder::<platform>
+  my( $self, $path ) = @_;
+  return $path;
+}
+
 sub check_build_done_marker {
   my $self = shift;
   return (-e 'build_done');
@@ -358,7 +408,9 @@ sub check_sha1sum {
   binmode($fh);
   $sha1->addfile($fh);
   close($fh);
-  return ($sha1->hexdigest eq $sha1sum) ? 1 : 0
+  my $_sha1sum = $sha1->hexdigest;
+  warn "###WARN## checksum for file $file is $_sha1sum but we expect $sha1sum\n" if $_sha1sum ne $sha1sum;
+  return ($_sha1sum eq $sha1sum) ? 1 : 0
 }
 
 sub patch_get_affected_files {
